@@ -29,6 +29,7 @@ from typing import (
 import aesara
 import aesara.tensor as at
 import numpy as np
+import pandas as pd
 import scipy.sparse as sps
 
 from aeppl.abstract import MeasurableVariable
@@ -50,6 +51,7 @@ from aesara.graph.fg import FunctionGraph
 from aesara.graph.op import Op, compute_test_value
 from aesara.sandbox.rng_mrg import MRG_RandomStream as RandomStream
 from aesara.scalar.basic import Cast
+from aesara.tensor.basic import _as_tensor_variable
 from aesara.tensor.elemwise import Elemwise
 from aesara.tensor.random.op import RandomVariable
 from aesara.tensor.random.var import (
@@ -142,6 +144,12 @@ def convert_observed_data(data):
         return floatX(ret)
 
 
+@_as_tensor_variable.register(pd.Series)
+@_as_tensor_variable.register(pd.DataFrame)
+def dataframe_to_tensor_variable(df: pd.DataFrame, *args, **kwargs) -> TensorVariable:
+    return at.as_tensor_variable(df.to_numpy(), *args, **kwargs)
+
+
 def change_rv_size(
     rv: TensorVariable,
     new_size: PotentialShapeType,
@@ -665,7 +673,7 @@ def join_nonshared_inputs(
 
     replace.update(shared)
 
-    xs_special = [aesara.clone_replace(x, replace, strict=False) for x in xs]
+    xs_special = [aesara.clone_replace(x, replace, rebuild_strict=False) for x in xs]
     return xs_special, inarray
 
 
@@ -677,6 +685,16 @@ def reshape_t(x, shape):
         return x[0]
 
 
+class PointFunc:
+    """Wraps so a function so it takes a dict of arguments instead of arguments."""
+
+    def __init__(self, f):
+        self.f = f
+
+    def __call__(self, state):
+        return self.f(**state)
+
+
 class CallableTensor:
     """Turns a symbolic variable with one input into a function that returns symbolic arguments
     with the one variable replaced with the input.
@@ -693,7 +711,7 @@ class CallableTensor:
         input: TensorVariable
         """
         (oldinput,) = inputvars(self.tensor)
-        return aesara.clone_replace(self.tensor, {oldinput: input}, strict=False)
+        return aesara.clone_replace(self.tensor, {oldinput: input}, rebuild_strict=False)
 
 
 class GeneratorOp(Op):
