@@ -1,4 +1,11 @@
-"""This submodule contains tools used to perform inference on ordinary differential equations."""
+"""
+This submodule contains tools used to perform inference on ordinary differential equations.
+
+Due to the nature of the model (as well as included solvers), ODE solution may perform slowly.
+Another library based on PyMC--sunode--has implemented Adams' method and BDF (backward differentation formula) using the very fast SUNDIALS suite of ODE and PDE solvers.
+It is much faster than the ``pm.ode`` implementation.
+More information about ``sunode`` is available at: https://github.com/aseyboldt/sunode.
+"""
 #   Copyright 2020 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
